@@ -1,6 +1,6 @@
 from typing import Dict, Any, List
-from lib import PostprocessorBase, ZIDSConfig, SharedArtifacts
-from lib.base_classes import PredictableBase
+from dsFramework import PostprocessorBase, ZIDSConfig, SharedArtifacts
+from dsFramework.base_classes import PredictableBase
 
 class generatedClass(PostprocessorBase):
     def __init__(self, config: ZIDSConfig, shared_artifacts: SharedArtifacts, name: str = 'generatedClassName',
